==> dl.php?src=linea21_1_7.zip: linea21/contents/help.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage content
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 'Content' module is used by 'Publication' and 'Workshop' modules
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('publication') && !$l21auth->hasRight('workshop')) ReloadIndex('admin');
///////////

$dirbox = $dir . "/help";
?>
<br
	class="brendstep brendstepfooter" />
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="icon-lifebuoy"></i> <?php echo _t('help','title');?></a>
<div id="aide"><?php if ($todo == 'add') 
{
  ?>
<p class="info"><?php echo _t('help','name'); ?> : <?php echo _t('contents','add'); ?></p>
<ul>
	<li><?php echo _t('contents','help_add1'); ?></li>
	<li><?php echo _t('contents','help_add2'); ?></li>
	<li><?php echo _t('contents','help_add3'); ?></li>
</ul>
  <?php
}
if ($todo == 'mod')
{
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('contents','mod');?></p>
<ul>
	<li><?php echo _t('contents','help_mod1');?></li>
	<li><?php echo _t('contents','help_mod2');?></li>
	<li><?php echo _t('contents','help_mod3');?></li>
</ul>
  <?php
}
if ($todo == 'det')
{
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('contents','det');?></p>
<ul>
	<li><?php echo _t('contents','help_det1');?></li>
	<li><?php echo _t('contents','help_det2');?></li>
</ul>
  <?php
}
if ($todo == 'sup')
{
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('contents','sup');?></p>
<ul>
	<li><?php echo _t('contents','help_sup1');?></li>
</ul>
  <?php
}
include_once(THEME_ADMIN_PATH."footer_content.php");
?>

==> dl.php?src=linea21_2_5_0.zip: linea21/contents/help.php <==
<?php
/**
 * Handle content for publication and workgroup report modules
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\modules\content
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 'Content' module is used by 'Publication' and 'Workshop' modules
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('publication') && !$l21auth->hasRight('workshop')) ReloadIndex('admin');
///////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="icon-lifebuoy"></i> <?php echo _t('help','title');?></a>
<div id="aide"><?php if ($todo == 'add')
{
  ?>
<p class="info"><?php echo _t('help','name'); ?> : <?php echo _t('contents','add'); ?></p>
<ul>
	<li><?php echo _t('contents','help_add1'); ?></li>
	<li><?php echo _t('contents','help_add2'); ?></li>
	<li><?php echo _t('contents','help_add3'); ?></li>
</ul>
  <?php
}
if ($todo == 'mod')
{
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('contents','mod');?></p>
<ul>
	<li><?php echo _t('contents','help_mod1');?></li>
	<li><?php echo _t('contents','help_mod2');?></li>
	<li><?php echo _t('contents','help_mod3');?></li>
</ul>
  <?php
}
if ($todo == 'det')
{
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('contents','det');?></p>
<ul>
	<li><?php echo _t('contents','help_det1');?></li>
	<li><?php echo _t('contents','help_det2');?></li>
</ul>
  <?php
}
if ($todo == 'sup')
{
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('contents','sup');?></p>
<ul>
	<li><?php echo _t('contents','help_sup1');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->
